@@ -617,6 +617,7 @@ class EllipsoidPlot(BasePlot):
         #### make ellipsoids
         ############################################################################################################################
 
+        if self.plot.enabled: self.currentFig.plotList = []
         for i, row in enumerate(self.rows):
 
             if self._type.is3d: zdata = np.ones(self.npoint) * self.zdata[row]
@@ -628,27 +629,27 @@ class EllipsoidPlot(BasePlot):
 
             # get ellipsoid boundary
 
-            bcrd = self.makeEllipsoid   ( covMat = subMatrix
-                                        , meanVec = self.center[row,:]
-                                        , npoint = self.npoint
-                                        )
+            bcrd = self.getEllipsoidBoundary( covMat = subMatrix
+                                            , meanVec = self.center[row,:]
+                                            , npoint = self.npoint
+                                            )
 
             if self.plot.enabled:
 
                 if self._type.is3d:
 
-                    self.currentFig.plot = self.currentFig.axes.plot( bcrd[0,:]
-                                                                    , bcrd[1,:]
-                                                                    , zdata
-                                                                    , **vars(self.plot.kws)
-                                                                    )
+                    self.currentFig.plotList.append( self.currentFig.axes.plot  ( bcrd[0,:]
+                                                                                , bcrd[1,:]
+                                                                                , zdata
+                                                                                , **vars(self.plot.kws)
+                                                                                ) )
 
                 else:
 
-                    self.currentFig.plot = self.currentFig.axes.plot( bcrd[0,:]
-                                                                    , bcrd[1,:]
-                                                                    , **vars(self.plot.kws)
-                                                                    )
+                    self.currentFig.plotList.append( self.currentFig.axes.plot  ( bcrd[0,:]
+                                                                                , bcrd[1,:]
+                                                                                , **vars(self.plot.kws)
+                                                                                ) )
 
         ############################################################################################################################
         #### add axes and title labels
@@ -688,14 +689,14 @@ class EllipsoidPlot(BasePlot):
         if reself: return self
 
     ################################################################################################################################
-    #### makeEllipsoid
+    #### getEllipsoidBoundary
     ################################################################################################################################
 
-    def makeEllipsoid   ( self
-                        , covMat
-                        , meanVec
-                        , npoint = 50
-                        ):
+    def getEllipsoidBoundary( self
+                            , covMat
+                            , meanVec
+                            , npoint = 50
+                            ):
         """
         
         Return the coordinates of the boundary of an 
